@@ -5,7 +5,7 @@
 # AIM:
 from abc import ABC
 import re
-from typing import Tuple
+from typing import Tuple, List
 from loguru import logger
 
 from .abc import Operation
@@ -102,26 +102,28 @@ class ShortHandler(Operation):
 
 
 class LongHandlerEN(Operation):
-    def __init__(self, symbols: dict, white_list_path: str, min_sentence_length: int = 5, name=None):
+    def __init__(self, symbols: dict, white_list: str, min_sentence_length: int = 5, name=None):
         super(LongHandlerEN, self).__init__('LongHandlerEN' if not name else name, symbols)
         self.is_end_symbol = condition.IsEndSymbolCN(symbols)
         self.is_comma = condition.IsComma(symbols)
         self.is_book_close = condition.IsBookClose(symbols)
         self.is_barcket_close = condition.IsBracketClose(symbols)
-        self.not_in_white_list = condition.NotInWhitelistDotEn(white_list_path)
+        self.not_in_white_list = condition.NotInWhitelistDotEn(white_list)
         self.is_next_with_space = condition.IsNextWithSpace(symbols)
         self.is_right_quota = condition.IsRightQuotaEn()
         self.min_sentence_length = min_sentence_length
         self.is_dialogue_gt = condition.DialogueIsGreaterThanEN(min_sentence_length)
+        self.is_bracket_gt = condition.BracketIsGreaterThan(min_sentence_length, symbols)
         self.space = self.symbols['all_symbols']
         self.blank = re.compile('^\s+$')
-        self.pre_index = 0
-        self.pre_sentence_start = 0
         self.is_s_left = condition.IsSQuota('left')
         self.is_s_right = condition.IsSQuota('right')
         self.is_s_en = condition.IsSQuota('en')
         self.is_sentence_dash = condition.IsSenetnecDash()
 
+        self.pre_index = 0
+        self.pre_sentence_start = 0
+
         self.quota_left = 0
         self.quota_en = 0
 
@@ -150,6 +152,8 @@ class LongHandlerEN(Operation):
         # self.weights = {k: i for k, i in sorted(self.weights.items(), key=lambda x: x[1])}
 
     def init_var(self):
+        self.pre_index = 0
+        self.pre_sentence_start = 0
         self.quota_left = 0
         self.quota_en = 0
         self.bracket_left = 0
@@ -275,7 +279,13 @@ class LongHandlerEN(Operation):
                 state.v_pointer = org_pointer
                 return min(i + 1, state.length - 1), True
 
-            elif self.is_s_quota_right(state) and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
+            elif self.symbols['bracket_right'].match(
+                    state.current_value) and sub_len > self.min_sentence_length and self.is_bracket_gt(state):
+                state.v_pointer = org_pointer
+                return min(i + 1, state.length - 1), True
+
+            elif self.is_s_quota_right(state) and state.pre_value[
+                -1] != 's' and sub_len > self.min_sentence_length and self.is_dialogue_gt(state) and \
                     (self.is_next_with_space(state) or state.v_pointer == state.length - 1):
                 state.v_pointer = org_pointer
                 return min(i + 1, state.length - 1), True
@@ -357,3 +367,20 @@ class EndState(Operation):
 
 class SpecialOperation(Operation, ABC):
     pass
+
+
+class CleanNode(SpecialOperation):
+    def __init__(self, node_list: List[Operation], name=None):
+        super(CleanNode, self).__init__('EndState' if not name else name, None)
+        self.node_list = node_list
+
+    def operate(self, state: StrSequence) -> StrSequence:
+        for node in self.node_list:
+            node.init_var()
+
+        # -- end state -- #
+        if state.sentence_list and state.sentence_start >= state.length or state.length == 0:
+            return state
+        else:
+            state.add_to_sentence_list()
+            return state
