@@ -1,13 +1,4 @@
-# -*- coding:utf-8 -*-
-# CREATED BY: jiangbohuai
-# CREATED ON: 2021/1/21 6:31 PM
-# LAST MODIFIED ON:
-# AIM:
-# white_list ="""
-# U.S.A.
-# U.S.
-# """
-white_list = """
+data = '''
 abbr.
 A.D.
 adj.
@@ -205,4 +196,34 @@ yr.
 G.L.O.W.
 U!S!A!
 Washingto, D.C.
-"""
\ No newline at end of file
+Jan.
+Feb.
+Mar.
+Apr.
+Jun.
+Jul.
+Aug.
+Sept.
+Sep.
+Oct.
+Nov.
+Dec.
+Mon.
+Tues.
+Wed.
+Thur.
+Fri.
+Sat.
+Sun.
+mm.
+dd.
+Co.,
+Ltd.,
+S.
+N. 
+S.E.
+H.K.
+N.Y.
+lng.
+D.C.
+'''
